Index: events/src/main/java/geniusweb/actions/Votes.java
===================================================================
--- events/src/main/java/geniusweb/actions/Votes.java	(revision 22)
+++ events/src/main/java/geniusweb/actions/Votes.java	(revision 24)
@@ -57,5 +57,6 @@
 	 * with power at most P.
 	 * 
-	 * @param otherVotes
+	 * @param otherVotes the {@link Votes}, usually from a previous round, that
+	 *                   this should extend.
 	 * @return true iff this extends the otherVotes.
 	 */
@@ -65,7 +66,6 @@
 		for (Vote vote : otherVotes.getVotes()) {
 			Vote myvote = getVote(vote.getBid());
-			if (myvote == null)
-				return false;
-			if (myvote.getMinPower() > vote.getMinPower())
+			if (myvote == null || myvote.getMinPower() > vote.getMinPower()
+					|| myvote.getMaxPower() < vote.getMaxPower())
 				return false;
 		}
Index: events/src/main/java/geniusweb/events/ActionEvent.java
===================================================================
--- events/src/main/java/geniusweb/events/ActionEvent.java	(revision 22)
+++ events/src/main/java/geniusweb/events/ActionEvent.java	(revision 24)
@@ -18,5 +18,5 @@
 	/**
 	 * 
-	 * @param action
+	 * @param action the {@link Action} that was done
 	 * @param time   the current time to use. see
 	 *               {@link System#currentTimeMillis()}.
Index: events/src/main/java/geniusweb/events/NegotiationEvent.java
===================================================================
--- events/src/main/java/geniusweb/events/NegotiationEvent.java	(revision 22)
+++ events/src/main/java/geniusweb/events/NegotiationEvent.java	(revision 24)
@@ -6,4 +6,6 @@
 import com.fasterxml.jackson.annotation.JsonTypeInfo;
 import com.fasterxml.jackson.annotation.JsonTypeInfo.As;
+
+import geniusweb.actions.Action;
 
 /**
Index: events/src/main/java/geniusweb/inform/Agreements.java
===================================================================
--- events/src/main/java/geniusweb/inform/Agreements.java	(revision 22)
+++ events/src/main/java/geniusweb/inform/Agreements.java	(revision 24)
@@ -51,6 +51,6 @@
 
 	/**
-	 * @param bid
-	 * @param parties
+	 * @param bid     a {@link Bid} to be added
+	 * @param parties {@link Set} of the {@link PartyId}s that accepted the bid
 	 * @return new Agreements, with the new bid/parties added.
 	 */
Index: events/src/main/java/geniusweb/inform/Inform.java
===================================================================
--- events/src/main/java/geniusweb/inform/Inform.java	(revision 22)
+++ events/src/main/java/geniusweb/inform/Inform.java	(revision 24)
@@ -7,5 +7,5 @@
 
 /**
- * base class of all information sent to the {@link Party}
+ * base class of all information sent to a Party
  */
 @JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.WRAPPER_OBJECT)
Index: events/src/main/java/geniusweb/inform/Settings.java
===================================================================
--- events/src/main/java/geniusweb/inform/Settings.java	(revision 22)
+++ events/src/main/java/geniusweb/inform/Settings.java	(revision 24)
@@ -2,4 +2,5 @@
 
 import java.util.HashMap;
+import java.util.Map;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
@@ -13,7 +14,6 @@
 
 /**
- * Informs a {@link Party} about all settings for the upcoming negotiation
- * session. This should be sent to a party one time, so that the party knows the
- * situation.
+ * Informs a Party about all settings for the upcoming negotiation session. This
+ * should be sent to a party one time, so that the party knows the situation.
  *
  */
@@ -31,10 +31,10 @@
 	 * @param protocol   the protocol used in this session
 	 * @param progress   the {@link Progress} object used for this session
-	 * @param parameters a Map<String, Object> containing initialization
-	 *                   parameters for this party. The Object can be a HashMap,
-	 *                   ArrayList, String, or number (Integer, Double, etc).
-	 *                   The Object should not be just any Object because
-	 *                   deserialization will work only with the mentioned
-	 *                   types.
+	 * @param parameters a {@link Map} &lt;String, Object&gt; containing
+	 *                   initialization parameters for this party. The Object
+	 *                   can be a HashMap, ArrayList, String, or number
+	 *                   (Integer, Double, etc). The Object should not be just
+	 *                   any Object because deserialization will work only with
+	 *                   the mentioned types.
 	 */
 	@JsonCreator
@@ -85,6 +85,6 @@
 	/**
 	 * 
-	 * @return a HashMap<String,Object> containing initialization parameters
-	 *         that can be used by the party.
+	 * @return a {@link HashMap}&lt;String,Object&gt; containing initialization
+	 *         parameters that can be used by the party.
 	 */
 	public HashMap<String, Object> getParameters() {

Index: events/src/main/java/geniusweb/inform/Finished.java
===================================================================
--- events/src/main/java/geniusweb/inform/Finished.java	(revision 22)
+++ events/src/main/java/geniusweb/inform/Finished.java	(revision 24)
@@ -15,9 +15,10 @@
 	 * The session finished (can be for any reason).
 	 * 
 	 * @param agreedBid the bid that was finally agreed on; null if no
 	 *                  agreement.
 	 */
 	@JsonCreator
 	public Finished(@JsonProperty("agreements") Agreements agreements) {
+		if (agreements == null)
+			throw new NullPointerException("Agreements can't be null");
 		this.agreements = agreements;
 	}
@@ -15,9 +15,10 @@
 	 * The session finished (can be for any reason).
 	 * 
-	 * @param agreedBid the bid that was finally agreed on; null if no
-	 *                  agreement.
+	 * @param agreements the {@link Agreements} that were finally agreed on.
 	 */
 	@JsonCreator